changeset 4116:1bc3d3b2cde1 SDL-1.2

Support both 10.2 and 10.3 PPC runtime SDK
author Sam Lantinga <slouken@libsdl.org>
date Sat, 29 Dec 2007 17:13:21 +0000
parents 63b57f6b6523
children dbb5f9556796
files build-scripts/fatbuild.sh
diffstat 1 files changed, 55 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/build-scripts/fatbuild.sh	Sat Dec 29 06:21:47 2007 +0000
+++ b/build-scripts/fatbuild.sh	Sat Dec 29 17:13:21 2007 +0000
@@ -10,26 +10,60 @@
 # Generic, cross-platform CFLAGS you always want go here.
 CFLAGS="-O3 -g -pipe"
 
-# PowerPC configure flags (10.3 runtime compatibility)
-# We dynamically load X11, so using the system X11 headers is fine.
-CONFIG_PPC="--build=`uname -p`-apple-darwin --host=powerpc-apple-darwin \
+# Locate Xcode SDK path
+SDK_PATH=/Developer/SDKs
+if [ ! -d $SDK_PATH ]; then
+    echo "Couldn't find SDK path"
+    exit 1
+fi
+
+# See if we can use 10.2 or 10.3 runtime compatibility
+if [ -d "$SDK_PATH/MacOSX10.2.8.sdk" ]; then
+    # PowerPC configure flags (10.2 runtime compatibility)
+    # We dynamically load X11, so using the system X11 headers is fine.
+    CONFIG_PPC="--build=`uname -p`-apple-darwin --host=powerpc-apple-darwin \
 --x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
 
-# PowerPC compiler flags
-CC_PPC="gcc-4.0 -arch ppc"
-CXX_PPC="g++-4.0 -arch ppc"
-CFLAGS_PPC=""
-CPPFLAGS_PPC="-DMAC_OS_X_VERSION_MIN_REQUIRED=1030 \
+    # PowerPC compiler flags
+    CC_PPC="gcc-3.3 -arch ppc"
+    CXX_PPC="g++-3.3 -arch ppc"
+    CFLAGS_PPC=""
+    CPPFLAGS_PPC="-DMAC_OS_X_VERSION_MIN_REQUIRED=1020 \
 -nostdinc \
--F/Developer/SDKs/MacOSX10.3.9.sdk/System/Library/Frameworks \
--I/Developer/SDKs/MacOSX10.3.9.sdk/usr/lib/gcc/powerpc-apple-darwin9/4.0.1/include \
--isystem /Developer/SDKs/MacOSX10.3.9.sdk/usr/include"
+-F$SDK_PATH/MacOSX10.2.8.sdk/System/Library/Frameworks \
+-I$SDK_PATH/MacOSX10.2.8.sdk/usr/include/gcc/darwin/3.3 \
+-isystem $SDK_PATH/MacOSX10.2.8.sdk/usr/include"
+
+    # PowerPC linker flags 
+    LFLAGS_PPC="-arch ppc \
+-L$SDK_PATH/MacOSX10.2.8.sdk/usr/lib/gcc/darwin/3.3 \
+-F$SDK_PATH/MacOSX10.2.8.sdk/System/Library/Frameworks \
+-Wl,-syslibroot,$SDK_PATH/MacOSX10.2.8.sdk"
+
+else # 10.2 or 10.3 SDK
+
+    # PowerPC configure flags (10.3 runtime compatibility)
+    # We dynamically load X11, so using the system X11 headers is fine.
+    CONFIG_PPC="--build=`uname -p`-apple-darwin --host=powerpc-apple-darwin \
+--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
 
-# PowerPC linker flags
-LFLAGS_PPC="-arch ppc -mmacosx-version-min=10.3 \
--L/Developer/SDKs/MacOSX10.3.9.sdk/usr/lib/gcc/powerpc-apple-darwin9/4.0.1 \
--F/Developer/SDKs/MacOSX10.3.9.sdk/System/Library/Frameworks \
--Wl,-syslibroot,/Developer/SDKs/MacOSX10.3.9.sdk"
+    # PowerPC compiler flags
+    CC_PPC="gcc-4.0 -arch ppc"
+    CXX_PPC="g++-4.0 -arch ppc"
+    CFLAGS_PPC=""
+    CPPFLAGS_PPC="-DMAC_OS_X_VERSION_MIN_REQUIRED=1030 \
+-nostdinc \
+-F$SDK_PATH/MacOSX10.3.9.sdk/System/Library/Frameworks \
+-I$SDK_PATH/MacOSX10.3.9.sdk/usr/lib/gcc/powerpc-apple-darwin9/4.0.1/include \
+-isystem $SDK_PATH/MacOSX10.3.9.sdk/usr/include"
+
+    # PowerPC linker flags
+    LFLAGS_PPC="-arch ppc -mmacosx-version-min=10.3 \
+-L$SDK_PATH/MacOSX10.3.9.sdk/usr/lib/gcc/powerpc-apple-darwin9/4.0.1 \
+-F$SDK_PATH/MacOSX10.3.9.sdk/System/Library/Frameworks \
+-Wl,-syslibroot,$SDK_PATH/MacOSX10.3.9.sdk"
+
+fi # 10.2 or 10.3 SDK
 
 # Intel configure flags (10.4 runtime compatibility)
 # We dynamically load X11, so using the system X11 headers is fine.
@@ -42,14 +76,14 @@
 CFLAGS_X86="-mmacosx-version-min=10.4"
 CPPFLAGS_X86="-DMAC_OS_X_VERSION_MIN_REQUIRED=1040 \
 -nostdinc \
--F/Developer/SDKs/MacOSX10.4u.sdk/System/Library/Frameworks \
--I/Developer/SDKs/MacOSX10.4u.sdk/usr/lib/gcc/i686-apple-darwin9/4.0.1/include \
--isystem /Developer/SDKs/MacOSX10.4u.sdk/usr/include"
+-F$SDK_PATH/MacOSX10.4u.sdk/System/Library/Frameworks \
+-I$SDK_PATH/MacOSX10.4u.sdk/usr/lib/gcc/i686-apple-darwin9/4.0.1/include \
+-isystem $SDK_PATH/MacOSX10.4u.sdk/usr/include"
 
 # Intel linker flags
 LFLAGS_X86="-arch i386 -mmacosx-version-min=10.4 \
--L/Developer/SDKs/MacOSX10.4u.sdk/usr/lib/gcc/i686-apple-darwin9/4.0.1 \
--Wl,-syslibroot,/Developer/SDKs/MacOSX10.4u.sdk"
+-L$SDK_PATH/MacOSX10.4u.sdk/usr/lib/gcc/i686-apple-darwin9/4.0.1 \
+-Wl,-syslibroot,$SDK_PATH/MacOSX10.4u.sdk"
 
 #
 # Find the configure script